@@ -19,6 +19,8 @@
 import pyparticles.animation.animation as pan
 
 import numpy as np
+import sys 
+
 
 import pyparticles.ogl.trackball as trk
 import pyparticles.ogl.axis_ogl as axgl
@@ -30,9 +32,13 @@ import pyparticles.ogl.draw_particles_ogl as drp
 from OpenGL.GL import *
 from OpenGL.GLUT import *
 from OpenGL.GLU import *
- 
 
-import time
+if sys.platform.startswith("win") :
+    from OpenGL.WGL import *
+    
+if sys.platform.startswith("linux") :
+    from OpenGL.GLX import *
+ 
 
 def InitGL( Width , Height , ReSizeFun ):
     """
@@ -363,6 +369,30 @@ def glut_print( x,  y,  font,  text, r,  g , b , a):
         glDisable(GL_BLEND) 
 
 
+if sys.platform.startswith("win"):
+    def SwapIntervalEXT( value ):   
+        import ctypes
+        # Open the opengl32.dll
+        gldll = ctypes.windll.opengl32
+        # define a function pointer prototype of *(GLuint program, GLenum pname, GLint value)
+        prototype = ctypes.WINFUNCTYPE( ctypes.c_int , ctypes.c_uint )
+        # Get the win gl func adress
+        fptr = gldll.wglGetProcAddress( 'wglSwapIntervalEXT' )
+        if fptr==0:
+            raise Exception( "wglSwapIntervalEXT ('wglSwapIntervalEXT ') returned a zero adress, which will result in a nullpointer error if used.")
+        _wglSwapIntervalEXT = prototype( fptr )
+        
+        _wglSwapIntervalEXT( value )
+        
+elif sys.platform.startswith("linux"):
+    def SwapIntervalEXT( value ):
+        pass
+else :
+    def SwapIntervalEXT( value ):
+        pass
+
+
+
 
 class AnimatedGl( pan.Animation ):
     def __init__(self):
@@ -634,6 +664,11 @@ class AnimatedGl( pan.Animation ):
             
         if self.vector_field != None :
             self.vector_field.ogl_init()
+        
+        try :            
+            SwapIntervalEXT(0)
+        except :
+            print( "ERROR: VSYNC not disabled" )
             
         
     def data_stream(self):
