@@ -29,8 +29,6 @@ import pyparticles.ode.midpoint_solver as mds
 import pyparticles.measures.kinetic_energy as ke
 import pyparticles.measures.total_energy as te
 
-import sys
-
 import pyparticles.animation.animated_ogl as aogl
 
 
@@ -38,7 +36,7 @@ def solar_system():
     """
     Solar system demo
     """
-    dt = 6*3600
+    dt = 3.0*3600.0
     steps = 1000000
     
     G = 6.67384e-11
