@@ -37,7 +37,8 @@ def parse_args():
                  "cat_spri" , 
                  "el_static" , 
                  "elmag_field" ,
-                 "fountain" ] ,
+                 "fountain" ,
+                 "galaxy"] ,
         dest="demo",
         default=None ,
         help="Execute the specified buildin demo"
@@ -62,4 +63,10 @@ def parse_args():
         help="print the current version and exit"
         )
     
+    parser.add_argument( "-a" , "--about",
+        action="store_true",
+        dest="about",
+        help="print the about message and exit"
+        )    
+    
     return parser.parse_args()
